@@ -35,7 +35,8 @@ class Client:
                 None
         '''
         self.client_uuid                        = client_uuid
-        
+        logging_client                          = google_clients.cloud_logging_client
+        self.__changelog_insert_logger          = logging_client.logger(client_uuid + '-changelog-logger')
         self.__google_big_query_storage_client  = google_clients.big_query_storage_v1_client
         self.__big_query_wrapper                = BigQuery.Wrapper(google_clients)
 
@@ -181,10 +182,11 @@ class Client:
             self.__google_big_query_storage_client, serialized_row, request_template, stream_name, parent)
         
         if response_future_1.done():
-            print('successfully inserted ' + str(changelog_data) + ' to CHANGELOG table')
+            self.__changelog_insert_logger.log_text('Inserted ' + str(changelog_data) + ' to changelog', severity='INFO')
             return True
 
-        Helpers.print_error('Failed to insert ' + str(changelog_data) + ' to CHANGELOG table')
+        self.__changelog_insert_logger.log_text('Failed to insert ' 
+            + str(changelog_data) + ' to CHANGELOG table', severity='ERROR')
         return False
 
 
