@@ -24,7 +24,7 @@ class Client:
     patient_table_name                  = ''
     table_fields                        = ["CLIENT_ID","MRN","PATIENT_ID","FIRSTNAME",
             "MIDDLENAME","LASTNAME","DOB","SEX","RACE", 'CHECKSUM','UPDATED_AT']
-
+    __patient_insert_logger             = None
     __proto_buf_dictionary              = None
     __google_big_query_client           = None
     __google_big_query_storage_client   = None
@@ -47,6 +47,8 @@ class Client:
             self.dataset_id + ".PATIENTS"
         self.__google_big_query_client          = google_clients.big_query_client
         self.__google_big_query_storage_client  = google_clients.big_query_storage_v1_client
+        logging_client                          = google_clients.cloud_logging_client
+        self.__patient_insert_logger            = logging_client.logger(client_uuid + '-patient-logger')
         self.__patient_table_update_client      = Update.Client(google_clients, client_uuid)
         self.__big_query_wrapper                = BigQuery.Wrapper(google_clients)
         self.__create_proto_buf_dictionary()
@@ -118,8 +120,6 @@ class Client:
             if self.__insert_patient_to_patients_table(i, overwrite=overwrite):
                 continue
             else:
-                Helpers.print_error("could not upload " + str(i) +
-                " to the PATIENTS table")
                 return False
         return True
 
@@ -137,7 +137,6 @@ class Client:
         '''
         now                         = datetime.datetime.utcnow()
         patient_data['UPDATED_AT']  = str(now).replace(' ','T')
-        print(patient_data)
         patient_mrn                 = patient_data['MRN']
         patient_id                  = Helpers.patient_hash(self.client_uuid, [patient_mrn])[0]
         patient_row                 = self.__get_patient_in_patients_table(patient_mrn, patient_id)
@@ -241,10 +240,14 @@ class Client:
             self.__google_big_query_storage_client, serialized_row, request_template, stream_name, parent)
         
         if response_future_1.done():
-            print('successfully inserted ' + str(patient_data) + ' to PATIENTS table')
+            self.__patient_insert_logger.log_text('successfully inserted ' + 
+                str(patient_data) + ' to PATIENTS table', severity='INFO')
+            print('successfully inserted Patient ' + str(patient_data['MRN']) + ' to PATIENTS table')
             return True
 
-        Helpers.print_error('Failed to insert ' + str(patient_data) + ' to PATIENTS table')
+        Helpers.print_error('Failed to insert Patient ' + str(patient_data['MRN']) + ' to PATIENTS table')
+        self.__patient_insert_logger.log_text('Failed to insert ' + 
+                str(patient_data) + ' to PATIENTS table', severity='ERROR')
         return False
             
     
