@@ -21,6 +21,7 @@ class Client:
     patient_table_name                  = ''
     overwrite                           = False
 
+    __patient_insert_logger             = None
     __google_big_query_client           = None
     __big_query_wrapper                 = None
     __holding_table_api                 = None
@@ -42,6 +43,8 @@ class Client:
             replace("-", "_")
         self.patient_table_name                 = self.dataset_id + ".PATIENTS"
         self.__google_big_query_client          = google_clients.big_query_client
+        logging_client                          = google_clients.cloud_logging_client
+        self.__patient_insert_logger            = logging_client.logger(client_uuid + '-patient-logger')
         self.__big_query_wrapper                = BigQuery.Wrapper(google_clients)
         self.__holding_table_api                = HoldingTable.Client(google_clients)
 
@@ -100,7 +103,12 @@ class Client:
         '''
         dml_query = self.__create_dml_update_query(patient_data, patient_row)
         if self.__big_query_wrapper.perform_query(dml_query) is None:
+            self.__patient_insert_logger.log_text('could not update patient info ' 
+            + patient_data, severity='WARNING')
             return False
+
+        self.__patient_insert_logger.log_text('updated patient info ' 
+            + patient_data, severity='INFO')
         return True
         
 
@@ -116,7 +124,7 @@ class Client:
                 string: The query we wish to run on the PATIENTS table
         '''
         table_name  = "indx-data-services."+self.client_uuid.replace('-','_')+".PATIENTS"
-        dml_query   = 'UPDATE ' + table_name + ' SET '
+        dml_query   = 'UPDATE `' + table_name + '` SET '
 
         for k in patient_data:
             dml_query += self.__populate_changed_keys_in_query(k, patient_row.get(k), patient_data[k])
@@ -181,7 +189,7 @@ class Client:
             if k == "CLIENT_ID" or k == "MRN" or k == "PATIENT_ID" or k == "UPDATED_AT":
                 continue
             
-            elif self.__is_new_data(patient_data[k], patient_row.get(k)):
+            elif self.__is_new_data(patient_data[k], patient_row.get(k)) or self.overwrite==True:
                 return True
 
         # nothing to update no need to make API call
@@ -216,12 +224,16 @@ class Client:
             Returns:
                 boolean: True if there is more data passed, False if not
         '''
+
         if input_value is not None and existing_value is None:
             # can update the file
             print(input_value, existing_value)
             return True
             
         if input_value is not None and existing_value is not None and self.overwrite == False:
+            if input_value == existing_value:
+                return False
             print_error("Cannot overide values in the PATIENT table using this command," +
             " try patients-table update command instead.")
-            return False
\ No newline at end of file
+        
+        return False
\ No newline at end of file
